@@ -25,14 +25,14 @@ const char css[] =
 	"	$('#tuning h2').addClass('hide');\n"
 	"	$('#tuning table').addClass('hide');\n"
 	"\n"
-	"	$('#top').append('<div class=\"SystemButton\"   onclick=\"toggleSystem()\">System Info<\\/div>');\n"
-	"	$('#top').append('<div class=\"SummaryButton\"  onclick=\"toggleSummary()\">Summary<\\/div>');\n"
-	"	$('#top').append('<div class=\"CpuidleButton\"  onclick=\"toggleCpuidle()\">CPU Idle<\\/div>');\n"
-	"	$('#top').append('<div class=\"CpufreqButton\"  onclick=\"toggleCpufreq()\">CPU Frequency<\\/div>');\n"
-	"	$('#top').append('<div class=\"SoftwareButton\" onclick=\"toggleSoftware()\">Software info<\\/div>');\n"
-	"	$('#top').append('<div class=\"DeviceButton\"   onclick=\"toggleDevice()\">Device Info<\\/div>');\n"
-	"	$('#top').append('<div class=\"TuningButton\"   onclick=\"toggleTuning()\">Tuning<\\/div>');\n"
-	"	$('#top').append('<div class=\"AllButton\"      onclick=\"toggleAll()\">All<\\/div>');\n"
+	"	$('#top').append('<div class=\"SystemButton\"   onclick=\"toggleSystem()\">System Info</div>');\n"
+	"	$('#top').append('<div class=\"SummaryButton\"  onclick=\"toggleSummary()\">Summary</div>');\n"
+	"	$('#top').append('<div class=\"CpuidleButton\"  onclick=\"toggleCpuidle()\">CPU Idle</div>');\n"
+	"	$('#top').append('<div class=\"CpufreqButton\"  onclick=\"toggleCpufreq()\">CPU Frequency</div>');\n"
+	"	$('#top').append('<div class=\"SoftwareButton\" onclick=\"toggleSoftware()\">Software info</div>');\n"
+	"	$('#top').append('<div class=\"DeviceButton\"   onclick=\"toggleDevice()\">Device Info</div>');\n"
+	"	$('#top').append('<div class=\"TuningButton\"   onclick=\"toggleTuning()\">Tuning</div>');\n"
+	"	$('#top').append('<div class=\"AllButton\"      onclick=\"toggleAll()\">All</div>');\n"
 	"	$('#top .SummaryButton').toggleClass('pressed');\n"
 	"\n"
 	"    }\n"
@@ -296,6 +296,11 @@ const char css[] =
 	"	text-align: left;\n"
 	"}\n"
 	"\n"
+	"th.tunable\n"
+	"{\n"
+	"	text-align: left;\n"
+	"}\n"
+	"\n"
 	"td.package_odd\n"
 	"{\n"
 	"	background-color: #E0ffE0;\n"
@@ -546,5 +551,10 @@ const char css[] =
 	"</head>\n"
 	"\n"
 	"<body>\n"
+	"\n"
+	"<div id='top'>\n"
+	"<h1><a href='#top'>&nbsp;</a></h1>\n"
+	"</div>\n"
+	"\n"
 ;
 #endif
